@@ -378,7 +378,7 @@ class Multilist(hildonize.get_app_class()):
 			else:
 				self.window.fullscreen ()
 			return True
-		elif event.keyval == gtk.keysyms.r and isCtrl:
+		elif event.keyval == gtk.keysyms.o and isCtrl:
 			self._toggle_rotate()
 			return True
 		elif event.keyval == gtk.keysyms.f and isCtrl:
